@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
-
-from clu.predicates import haspyattr
 from clu.exporting import Exporter
 
-exporter = Exporter()
+exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 # DICT FUNCTIONS: dictionary-merging
@@ -14,18 +12,18 @@ def merge_two(one, two, cls=dict):
     """ Merge two dictionaries into an instance of the specified class
         Based on this docopt example source: https://git.io/fjCZ6
     """
+    from clu.predicates import getitem
     if not cls:
         cls = type(one)
     keys = frozenset(one) | frozenset(two)
-    merged = ((key, one.get(key, None) or two.get(key, None)) for key in keys)
+    merged = ((key, getitem(one, key) or getitem(two, key)) for key in keys)
     return cls(merged)
 
 @export
-def merge_as(*dicts, **overrides):
+def merge_as(*dicts, cls=dict, **overrides):
     """ Merge all dictionary arguments into a new instance of the specified class,
         passing all additional keyword arguments to the class constructor as overrides
     """
-    cls = overrides.pop('cls', dict)
     if not cls:
         cls = len(dicts) and type(dicts[0]) or dict
     merged = cls(**overrides)
@@ -47,10 +45,20 @@ def merge(*dicts, **overrides):
 @export
 def asdict(thing):
     """ asdict(thing) → returns either thing, thing.__dict__, or dict(thing) as necessary """
+    from clu.predicates import haspyattr
+    from clu.typology import ismapping
     if isinstance(thing, dict):
         return thing
     if haspyattr(thing, 'dict'):
-        return thing.__dict__
+        return asdict(thing.__dict__)
+    if hasattr(thing, '_asdict'):
+        return asdict(thing._asdict())
+    if hasattr(thing, 'to_dict'):
+        return asdict(thing.to_dict())
+    if hasattr(thing, 'dict'):
+        return asdict(thing.dict)
+    if ismapping(thing):
+        return dict(thing)
     return dict(thing)
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
