@@ -14,9 +14,10 @@ from clu.constants.consts import λ, φ
 from clu.constants.polyfills import long, unicode, numpy
 from clu.constants.polyfills import HashableABC, SequenceABC, Path
 from clu.constants.polyfills import Mapping, MutableMapping
+from clu.enums import alias
 from clu.exporting import Exporter
 
-from clu.predicates import (isclasstype,
+from clu.predicates import (isclasstype, isenum,
                             allpyattrs, haspyattr, nopyattr,
                             isiterable, haslength,
                             getpyattr, or_none,
@@ -89,8 +90,9 @@ path_types = string_types + bytes_types + path_classes
 file_types = (io.TextIOBase, io.BufferedIOBase, io.RawIOBase, io.IOBase)
 
 dict_types = { dict, OrderedDict, DefaultDict, Counter }
+namespace_types = { types.SimpleNamespace, types.Namespace }
 mapping_types = { Mapping, MutableMapping }
-mapping_classes = dict_types | mapping_types
+mapping_classes = dict_types | namespace_types | mapping_types
 
 function_types = Λ = (types.Function,
                       types.Method,
@@ -113,18 +115,27 @@ callable_types += attrs(types, 'Coroutine',
 # PREDICATE FUNCTIONS: is<something>() unary-predicates, many of which make use
 # of the aforementioned typelists:
 
+# Path types:
 ispathtype = lambda cls: issubclass(cls, path_types)
 ispath = lambda thing: subclasscheck(thing, path_types) or haspyattr(thing, 'fspath')
 isvalidpath = lambda thing: ispath(thing) and os.path.exists(os.path.expanduser(thing))
 
+# Abstract items and context managers:
 isabstractmethod = lambda method: getpyattr(method, 'isabstractmethod', False)
 isabstract = lambda thing: bool(pyattr(thing, 'abstractmethods', 'isabstractmethod'))
 isabstractcontextmanager = lambda cls: subclasscheck(cls, contextlib.AbstractContextManager)
 iscontextmanager = lambda cls: allpyattrs(cls, 'enter', 'exit') or isabstractcontextmanager(cls)
 
+# Enum and enum alias types:
+isaliasdescriptor = lambda thing: isinstance(thing, alias)
+hasmembers = lambda thing: isenum(thing) and haspyattr(thing, 'members')
+hasaliases = lambda thing: isenum(thing) and haspyattr(thing, 'aliases')
+
+# Typelist predicates:
 isnumber = lambda thing: subclasscheck(thing, numeric_types)
 isnumeric = lambda thing: subclasscheck(thing, numeric_types)
 iscomplex = lambda thing: subclasscheck(thing, complex)
+ismapping = lambda thing: subclasscheck(thing, mapping_classes)
 isarray = lambda thing: subclasscheck(thing, array_types)
 isscalar = lambda thing: subclasscheck(thing, scalar_types)
 isstring = lambda thing: subclasscheck(thing, string_types)
@@ -140,6 +151,7 @@ issequence = lambda thing: isinstance(thing, SequenceABC)
 isxlist = lambda predicate, thinglist: issequence(thinglist) and predicate_all(predicate, thinglist)
 isxtypelist = lambda predicate, thinglist: istypelist(thinglist) and predicate_all(predicate, thinglist)
 
+# Typelist list-type predicates (?!)
 ispathtypelist = predicate_all(lambda thing: isclasstype(thing) and ispathtype(thing))
 ispathlist = predicate_all(ispath)
 isvalidpathlist = predicate_all(isvalidpath)
@@ -147,6 +159,7 @@ isvalidpathlist = predicate_all(isvalidpath)
 isnumberlist = predicate_all(isnumber)
 isnumericlist = predicate_all(isnumeric)
 iscomplexlist = predicate_all(iscomplex)
+ismappinglist = predicate_all(ismapping)
 isarraylist = predicate_all(isarray)
 isscalarlist = predicate_all(isscalar)
 isstringlist = predicate_all(isstring)
@@ -197,9 +210,15 @@ export(isabstract,                          doc="isabstract(thing) → boolean p
 export(isabstractcontextmanager,            doc="isabstractcontextmanager(thing) → boolean predicate, True if `thing` decends from `contextlib.AbstractContextManager`")
 export(iscontextmanager,                    doc="iscontextmanager(thing) → boolean predicate, True if `thing` is a context manager (either abstract or concrete)")
 
+export(isaliasdescriptor,                       name='isaliasdescriptor',
+                                                doc="isaliasdescriptor(thing) → boolean predicate, returns True if `thing` is an aliasing descriptor bound to an existing Enum member")
+export(hasmembers,      name='hasmembers',      doc="hasmembers(cls) → boolean predicate, True if `cls` descends from Enum and has 1+ items in its `__members__` dict")
+export(hasaliases,      name='hasaliases',      doc="hasaliases(cls) → boolean predicate, True if `cls` descends from Enum and has 1+ items in its `__aliases__` dict")
+
 export(isnumber,        name='isnumber',    doc="isnumber(thing) → boolean predicate, True if `thing` is a numeric type or an instance of same")
 export(isnumeric,       name='isnumeric',   doc="isnumeric(thing) → boolean predicate, True if `thing` is a numeric type or an instance of same")
 export(iscomplex,       name='iscomplex',   doc="iscomplex(thing) → boolean predicate, True if `thing` is a complex numeric type or an instance of same")
+export(ismapping,       name='ismapping',   doc="ismapping(thing) → boolean predicate, True if `thing` is a mapping (dict-ish) type or an instance of same")
 export(isarray,         name='isarray',     doc="isarray(thing) → boolean predicate, True if `thing` is an array type or an instance of same")
 export(isscalar,        name='isscalar',    doc="isscalar(thing) → boolean predicate, True if `thing` is a numpy scalar numeric type or an instance of same")
 export(isstring,        name='isstring',    doc="isstring(thing) → boolean predicate, True if `thing` is a string type or an instance of same")
@@ -224,6 +243,7 @@ export(isvalidpathlist, name='isvalidpathlist', doc="isvalidpathlist(thinglist)
 export(isnumberlist,    name='isnumberlist',    doc="isnumberlist(thinglist) → boolean predicate, True if `thinglist` is a sequence of numeric types")
 export(isnumericlist,   name='isnumericlist',   doc="isnumericlist(thinglist) → boolean predicate, True if `thinglist` is a sequence of numeric types")
 export(iscomplexlist,   name='iscomplexlist',   doc="iscomplexlist(thinglist) → boolean predicate, True if `thinglist` is a sequence of complex numeric types")
+export(ismappinglist,   name='ismappinglist',   doc="ismappinglist(thinglist) → boolean predicate, True if `thinglist` is a sequence of mapping (dict-ish) types")
 export(isarraylist,     name='isarraylist',     doc="isarraylist(thinglist) → boolean predicate, True if `thinglist` is a sequence of array types")
 export(isscalarlist,    name='isscalarlist',    doc="isscalarlist(thinglist) → boolean predicate, True if `thinglist` is a sequence of numpy scalar numeric types")
 export(isstringlist,    name='isstringlist',    doc="isstringlist(thinglist) → boolean predicate, True if `thinglist` is a sequence of string types")
